#ifndef TRIG_SAMPLE_H
#define TRIG_SAMPLE_H

#include <windows.h>
#include <richedit.h>
#include <commctrl.h>
#include <iostream>
#include <fstream>
#include <cstring>
#include <cstdarg>

// LE650H2 Lib
#include "LEU_LIB.h"

// LE Control functions & User defined utils
#include "MyLEU.h"

// measurement cycle [ms]
#define LEMES_REP 500
// timeout = [ cycle x times ]
#define LERUN_TIMES 60

// control IDs //
#define ID_EDIT_ST 1001
#define ID_EDIT_SER 1002
#define ID_EDIT_TRG1 1003
#define ID_EDIT_TRG2 1004
#define ID_BTN_SER 1101
#define ID_BTN_RUN 1102
#define ID_BTN_STOP 1103
#define ID_BTN_SAVE 1104
#define ID_BTN_DCON 1105
#define ID_TXT_CON 1201
#define ID_TXT_RUN 1202
#define ID_TXT_SOF 1203
#define ID_TXT_TIME 1204
#define ID_TIMER 1301
#define ID_GRID 1401
#define ID_CHK_SOF 1501
#define ID_CHK_PING 1502
#define ID_CHK_INNAK 1503
#define ID_CHK_SETUP 1504

// Window Size //
#define MWIN_WID 800
#define MWIN_HGT 600

// control definitions 
#define ST_MAX_LINE 30 // max. status log lines
#define HGT_S 20 // small size
#define WID_N 80 // normal size
#define HGT_N 25
#define WID_L 120 // large size
#define WID_LL 160 // extra large size

// status log size/pos
#define PX_STAT 30
#define PY_STAT 420
#define WD_STAT 740
#define HT_STAT 130

// connection controls position
#define PX_CON 30
#define PY_CON 30

// trigger controls position
#define PX_TRG 30
#define PY_TRG 130

// run controls position
#define PX_RUN 30
#define PY_RUN 200

// grid size/pos
#define PX_GRID 230
#define PY_GRID 60
#define WD_GRID 540
#define HT_GRID 330

#define GRID_COLS 10 // N columns
#define GRID_LINES 65535 // Max. lines

// sof & time labels
#define PX_SOF 230
#define PY_SOF 40

// filter control pos
#define PX_FLT 30
#define PY_FLT 280

// save button pos
#define PX_SAVE 680
#define PY_SAVE 25

// window handlers
HWND hEditSt;
HWND hEditSer;
HWND hEditTrg1;
HWND hEditTrg2;
HWND hTextCon;
HWND hTextRun;
HWND hTextTrg1;
HWND hTextTrg2;
HWND hTextSOF;
HWND hTextTime;
HWND hBtnSer;
HWND hBtnRun;
HWND hBtnStop;
HWND hBtnSave;
HWND hBtnDcon;
HWND hGrid;
HWND hChkSOF;
HWND hChkPING;
HWND hChkINNAK;
HWND hChkSETUP;

// Global pointers
HWND hWndMain; // Main window handler
MyLEU *LE650;    // LEU control class
HINSTANCE hRcTxlib; // status log window

// Prototypes
int StatusMsg(const char * mstr);
int StatusMsgSP(const char * fmt, ...);
void NoticeUnconnected();
void NoticeStopping();
void NoticeRunning();
int CheckLE();
int OnConnect();
int OnDisConnect();
int OnTrgSet();
int OnFilterSet();
int OnRun();
int OnStop();
int OnTimer();
int OnSave(OPENFILENAME ofn);
void AddColumn(HWND _wnd, int wid, char * label, int id);
void AddItem(HWND _wnd, int line, int col, const char * str);
int WriteLine(int lineno, int disp);

#endif



