#ifndef MYLEU_H
#define MYLEU_H

#define BUF_KB 1024 // buffer size in KByte

#define MYUSB_MAXPACKET 4096
#define MYUSB_ENDFLAG1 0x1
#define MYUSB_ENDFLAG2 0x2
#define MYUSB_PREFLAG  0x4

/// USB transaction data struct ///
typedef struct{
	double time;
	int speed;
	int split;
	int event_id;
	int token_pid;
	uint8_t addr;
	uint8_t endp;
	int data_pid;
	int hand_pid;
	int data_length;
	uint16_t frame;
	double busreset_time;
	int trig_no;
	double vbus_V;
	double vbus_I;
	uint8_t data[MYUSB_MAXPACKET];
	int endflag;	
} USBTrans;

// for user filtering 
#define MYFILTER_NONE 0
#define MYFILTER_ONLYSETUP 1

typedef struct{
	int disp_setup;
	int disp_in;
	int disp_out;
} MyFilter;

/// for display ///
#define MYDISP_NCHR 8
#define MYDISP_DATALEN (MYDISP_NCHR * 3 + 4)

#define FLAG_DISP_SOF 0  // 1 to eneble SOF output to the main grid (heavy)
// MyLEU::ReadData() also restricting SOF decode/display
#define FLAG_DISP_PING 1 // 1 to enable PING output to the main grid (heavy)

// display flags of transaction
#define DISP_PID 0x1
#define DISP_VALUE 0x2
#define DISP_ADDR 0x4
#define DISP_ENDP 0x8
#define DISP_DATA 0x10
#define DISP_HAND 0x20
#define DISP_SPD 0x40
#define DISP_NTIMES 0x80
#define DISP_NOLINE 0x100
#define DISP_DATA_ID 0x200
#define DISP_DATA_LEN 0x400

// pre-defined strings
#define NAME_BUSRESET 0
#define NAME_SUSPEND 1
#define NAME_DISCONNECT 2
#define NAME_DEVCHIRP 3
#define NAME_HUBCHIRP 4
#define NAME_VBUS 5
#define NAME_TRIG 6
#define NAME_TRIGEX 7
#define NAME_RSV 8
#define NAME_PING 9
#define NAME_SOF 10
#define NAME_SPLIT 11
#define NAME_IN 12
#define NAME_OUT 13
#define NAME_SETUP 14

#define NAME_LSPD 15
#define NAME_FSPD 16
#define NAME_HSPD 17

#define NAME_DATA0 18
#define NAME_DATA1 19
#define NAME_DATA2 20
#define NAME_MDATA 21

#define NAME_NAK 22
#define NAME_ACK 23
#define NAME_NYET 24
#define NAME_STALL 25
#define NAME_ERR 26

#define NAME_NONE 27

/// Transaction reconstruction class ///
class MyTrans{
public:
	MyTrans();
	~MyTrans();

	int dispflag;
	double last_time;
	int Append(LEU_data &ldata); // append a packet to transaction
	const char * GetDispStr(int did); // Get disply strings
	int NextTrans(MyFilter flt); // move to the next stored transaction

private:
	int transflag;
	USBTrans trans; // current transaction (may be incomplete)
	USBTrans trans_prev; // previous transaction
	USBTrans trans_last; // last valid transaction decoded

	int nSameTrans;
	int SameTrans(USBTrans &t1, USBTrans &t2);
	void CopyTrans(USBTrans &t1, USBTrans &t2);

	int GetStrings(int tID);
	int NewTrans();
	void ClearAll();
	void Clear(USBTrans &t_trans);

	// packet analysis
	int IsNewTrans(USBTrans trans, int pid);
	int IsEndTrans(int pid);
	int IsToken(int pid);
	int IsHandShake(int pid);

	int name_id;
	int spd_id;
	int hand_id;
	int data_id;

	//display string buffer
	char buf_value[50];
	char buf_data[3 * MYDISP_NCHR +4];
	char buf_tmp[20];
};

/// LE650 user control class ///
class MyLEU{
public:
	int LE; // LE650 device handler

	uint16_t last_sof;

	MyLEU(int timeout);
	~MyLEU();
	int InitSettings();
	int ConnectNoSerial();
	int Connect(char * serial);
	int DisConnect();
	int Run();
	int Stop();
	int SetMyTrig(int len, uint8_t * trgdata, int len2, uint8_t * trgdata2);
	int SetHardFilter(uint16_t flt);
	int SetSoftFilter(int flt);
	int EndRead();
	int ReadData();
	int AppendData();
	int GetNextTrans();
	const char * GetDispStr(int did);
	char * GetErrStatus();
	int CheckState();
	double GetLastTime();

private:
	int iTimer;
	int iTimeout;
	LEU_data ldata;
	MyTrans trans;
	MyFilter sflt;
};

#endif